@@ -7,17 +7,30 @@
 ;; Created:    Oct 2004
 ;; Keywords:   python pymacs emacs
 
-;; This software is provided as-is, without express or implied warranty.
-;; Permission to use, copy, modify, distribute or sell this software,
-;; without fee, for any purpose and by any individual or organization, is
-;; hereby granted, provided that the above copyright notice and this
-;; paragraph appear in all copies.
+;; This program is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation, either version 3 of the License, or
+;; (at your option) any later version.
 
+;; This program is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+
+;; You should have received a copy of the GNU General Public License
+;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+;;; Commentary:
 ;; Along with pycomplete.py this file allows programmers to complete Python
 ;; symbols within the current buffer.  See pycomplete.py for the Python side
 ;; of things and a short description of what to expect.
 
-(require 'pymacs)
+;; BAW 2012-09-28: pymacs may not be installed on Debian.
+(condition-case nil
+    (require 'pymacs)
+  (file-error nil))
+
+(eval-when-compile (require 'cl))
 
 (pymacs-load "pycomplete")
 
@@ -403,7 +416,10 @@ Should be called from python-mode-hook. Keys are set when
   (cond
    ((fboundp 'auto-complete-mode)
     (require 'auto-complete-pycomplete)
-    (setq ac-sources '(ac-source-pycomplete)))
+    (setq ac-sources
+          (if (boundp 'py-complete-ac-sources)
+              py-complete-ac-sources
+            '(ac-source-pycomplete))))
    ((fboundp 'company-mode)
     (company-mode t)
     (require 'company-pycomplete)
