@@ -1,5 +1,5 @@
 #! /usr/bin/env python
 # -*- coding: utf-8 -*-
 
-print u'\xA9'
+print(u'\xA9')
 
